@@ -54,6 +54,9 @@
 /** Default padding used troughout the GTK+ frontend. */
 #define DEFAULT_PADDING 6
 
+/* Unused area between "aligned" columns in pango units. */
+#define COLUMN_SPACING 20000
+
 #ifdef DI_UDEB
 /** Paths to the directory containing images used by the GTK+ frontend. */
 # define BASE_IMAGE_PATH \
@@ -69,7 +72,7 @@
  * @see create_banner()
  */
 #define LOGO_IMAGE_PATH \
-    BASE_IMAGE_PATH "/logo_debian.png"
+    BASE_IMAGE_PATH "/logo_installer.png"
 
 /** Can the progress be canceled within the current frontend run? */
 #define CAN_CANCEL_PROGRESS(Frontend) \
@@ -79,6 +82,10 @@
 #define CAN_GO_BACK(Frontend) \
     (Frontend->methods.can_go_back(Frontend, Frontend->questions))
 
+/** Should tab separated fields be aligned in select and multiselect? */
+#define CAN_ALIGN(Frontend) \
+    (Frontend->methods.can_align(Frontend, Frontend->questions))
+
 /** Is the question the only one in the current GO? */
 #define IS_QUESTION_SINGLE(Question) \
     (NULL == Question->prev && NULL == Question->next)
@@ -154,6 +161,12 @@ void cdebconf_gtk_set_answer_notok(struct frontend * fe);
  */
 void cdebconf_gtk_set_answer_goback(struct frontend * fe);
 
+/** Display help for the current question.
+ *
+ * @param fe cdebconf frontend
+ */
+void cdebconf_gtk_help(struct frontend * fe);
+
 /** Force cdebconf to quit.
  *
  * This function is currently used when the main window is closed.
